// clipView.cpp : implementation of the CClipView class
//

#include "stdafx.h"
#include "clip.h"

#include "clipDoc.h"
#include "clipView.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CClipView

IMPLEMENT_DYNCREATE(CClipView, CFormView)

BEGIN_MESSAGE_MAP(CClipView, CFormView)
	//{{AFX_MSG_MAP(CClipView)
	ON_COMMAND(ID_EDIT_COPY, OnEditCopy)
	ON_COMMAND(ID_EDIT_CUT, OnEditCut)
	ON_COMMAND(ID_EDIT_PASTE, OnEditPaste)
	ON_COMMAND(ID_EDIT_UNDO, OnEditUndo)
	ON_UPDATE_COMMAND_UI(ID_EDIT_PASTE, OnUpdateEditPaste)
	ON_UPDATE_COMMAND_UI(ID_EDIT_COPY, OnUpdateEditCopy)
	ON_UPDATE_COMMAND_UI(ID_EDIT_CUT, OnUpdateEditCut)
	ON_UPDATE_COMMAND_UI(ID_EDIT_UNDO, OnUpdateEditUndo)
	//}}AFX_MSG_MAP
	// Standard printing commands
	ON_COMMAND(ID_FILE_PRINT, CFormView::OnFilePrint)
	ON_COMMAND(ID_FILE_PRINT_DIRECT, CFormView::OnFilePrint)
	ON_COMMAND(ID_FILE_PRINT_PREVIEW, CFormView::OnFilePrintPreview)
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CClipView construction/destruction

CClipView::CClipView()
	: CFormView(CClipView::IDD)
{
	//{{AFX_DATA_INIT(CClipView)
		// NOTE: the ClassWizard will add member initialization here
	//}}AFX_DATA_INIT
	
	nEditID = 0;
	UndoEnabled = FALSE;
	CutEnabled = TRUE;
	CopyEnabled = TRUE;
	PasteEnabled = FALSE;
}

CClipView::~CClipView()
{
}

void CClipView::DoDataExchange(CDataExchange* pDX)
{
	CFormView::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CClipView)
		// NOTE: the ClassWizard will add DDX and DDV calls here
	//}}AFX_DATA_MAP
}

BOOL CClipView::PreCreateWindow(CREATESTRUCT& cs)
{
	// TODO: Modify the Window class or styles here by modifying
	//  the CREATESTRUCT cs

	return CFormView::PreCreateWindow(cs);
}

/////////////////////////////////////////////////////////////////////////////
// CClipView printing

BOOL CClipView::OnPreparePrinting(CPrintInfo* pInfo)
{
	// default preparation
	return DoPreparePrinting(pInfo);
}

void CClipView::OnBeginPrinting(CDC* /*pDC*/, CPrintInfo* /*pInfo*/)
{
	// TODO: add extra initialization before printing
}

void CClipView::OnEndPrinting(CDC* /*pDC*/, CPrintInfo* /*pInfo*/)
{
	// TODO: add cleanup after printing
}

void CClipView::OnPrint(CDC* pDC, CPrintInfo*)
{
	// TODO: add code to print the controls
}

/////////////////////////////////////////////////////////////////////////////
// CClipView diagnostics

#ifdef _DEBUG
void CClipView::AssertValid() const
{
	CFormView::AssertValid();
}

void CClipView::Dump(CDumpContext& dc) const
{
	CFormView::Dump(dc);
}

CClipDoc* CClipView::GetDocument() // non-debug version is inline
{
	ASSERT(m_pDocument->IsKindOf(RUNTIME_CLASS(CClipDoc)));
	return (CClipDoc*)m_pDocument;
}
#endif //_DEBUG

/////////////////////////////////////////////////////////////////////////////
// CClipView message handlers

BOOL CClipView::OnCmdMsg(UINT nID, int nCode, void* pExtra, AFX_CMDHANDLERINFO* pHandlerInfo) 
{
	if( nCode== EN_SETFOCUS ) // Entering an Edit control
	{
		nEditID = nID; // Save it's ID
		SetEditPaste( SEP_DETERMINE ); 

	}
	else
	if( nCode== EN_KILLFOCUS )	// We left an edit control
	{
		nEditID = 0;	// Clear out the ID
		SetEditPaste( SEP_DETERMINE );
	}
	return CFormView::OnCmdMsg(nID, nCode, pExtra, pHandlerInfo);
}

void CClipView::OnEditCopy() 
{
	if( nEditID )
	{
		CEdit* pEdit = (CEdit*)GetDlgItem( nEditID );
		pEdit->Copy();
	}
}

void CClipView::OnEditCut() 
{
	if( nEditID )
	{
		CEdit* pEdit = (CEdit*)GetDlgItem( nEditID );
		pEdit->Cut();
	}
}

void CClipView::OnEditPaste() 
{
	if( nEditID )
	{
		CEdit* pEdit = (CEdit*)GetDlgItem( nEditID );
		pEdit->Paste();
		CloseClipboard();
	}
}

void CClipView::OnEditUndo() 
{
	if( nEditID )
	{
		CEdit* pEdit = (CEdit*)GetFocus();
		pEdit->Undo();
	}
}

void CClipView::OnUpdateEditPaste(CCmdUI* pCmdUI) 
{
	SetEditPaste( SEP_DETERMINE );
	pCmdUI->Enable( PasteEnabled );	
}

void CClipView::OnUpdateEditCopy(CCmdUI* pCmdUI) 
{
	SetEditPaste( SEP_DETERMINE );
	pCmdUI->Enable( CopyEnabled );	
}

void CClipView::OnUpdateEditCut(CCmdUI* pCmdUI) 
{
	SetEditPaste( SEP_DETERMINE );
	pCmdUI->Enable( CutEnabled );	
}

void CClipView::OnUpdateEditUndo(CCmdUI* pCmdUI) 
{
	SetEditPaste( SEP_DETERMINE );
	pCmdUI->Enable( UndoEnabled );	
}


void CClipView::SetEditPaste(int Mode)
{
	if( !nEditID )
	{
		UndoEnabled=FALSE;
		CutEnabled=FALSE;
		CopyEnabled=FALSE;
		PasteEnabled=FALSE;
		return;
	}

	UndoEnabled=TRUE;
	CutEnabled=TRUE;
	CopyEnabled=TRUE;
		
	if( Mode == SEP_DETERMINE )
	{
		if( OpenClipboard() )
		{
			if( GetClipboardData( CF_TEXT ) )
				Mode = SEP_ON;
			else
				Mode = SEP_OFF;
			CloseClipboard();
		}
	}
	PasteEnabled=(Mode==SEP_ON?TRUE:FALSE);
}


